#
#  Script for producing WCS coordinate lists matched to
#  photometry (magd.?) and source (xycood.?) lists produced
#  by do_nsphot.cl and pdump_xymag.cl
#
#  Input image filenames are I?_"name".fits
#  Input coordinate lists are xycood.?
#
#  Output WCS coordinate lists are wcscood.?
#
#  Works on any of 4 IRAC channels
#
# (c) 2005 Mike Schuster (mschuster@cfa.harvard.edu)
# (c) 2005 SAO - Smithsonian Astrophysical Observatory
#
#  v1.2 - 11 JAN 2006
#  several previous versions by several authors, SAO
#

procedure do_wcsctran (filename)

string filename

begin

  string exfile
  string name
  name = filename

  if (access("wcscood.1") || access("wcscood.2") || access("wcscood.3") || access("wcscood.4"))
    delete("wcscood.*",verify-)

  unlearn("wcsctran")

  exfile = "I1_"//name//".fits"
  if (access(exfile) && access("xycood.1")) {
    wcsctran(image=exfile, input="xycood.1", output="wcscood.1", inw="log", outw="wor", formats="%12.3H %12.2h")
  }

  exfile = "I2_"//name//".fits"
  if (access(exfile) && access("xycood.2")) {
    wcsctran(image=exfile, input="xycood.2", output="wcscood.2", inw="log", outw="wor", formats="%12.3H %12.2h")
  }

  exfile = "I3_"//name//".fits"
  if (access(exfile) && access("xycood.3")) {
    wcsctran(image=exfile, input="xycood.3", output="wcscood.3", inw="log", outw="wor", formats="%12.3H %12.2h")
  }

  exfile = "I4_"//name//".fits"
  if (access(exfile) && access("xycood.4")) {
    wcsctran(image=exfile, input="xycood.4", output="wcscood.4", inw="log", outw="wor", formats="%12.3H %12.2h")
  }

end
