#
#  Script for producing extracted source and photometry
#  lists using photometry lists mag.? produced by
#  do_nsphot.cl
#
#  Input photometry lists are mag.?
#
#  Output source lists are xycood.?
#  Output photometry lists are magd.?
#
#  Removes "bad" data from extracted lists
#
#  Works on any of 4 IRAC channels
#
# (c) 2005 Mike Schuster (mschuster@cfa.harvard.edu)
# (c) 2005 SAO - Smithsonian Astrophysical Observatory
#
#  v1.2 - 10 JAN 2006
#

procedure pdump_xymag(filename)

string filename

begin

  if (access("magd.1") || access("magd.2") || access("magd.3") || access("magd.4"))
    delete("magd.*",verify-)

  if (access("xycood.1") || access("xycood.2") || access("xycood.3") || access("xycood.4"))
    delete("xycood.*",verify-)

  unlearn("pdump")

  if (access("mag.1")) {
    pdump(infile="mag.1", fields="MAG,MERR", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "magd.1");
    pdump(infile="mag.1", fields="XCENTER,YCENTER", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "xycood.1")
  }

  if (access("mag.2")) {
    pdump(infile="mag.2", fields="MAG,MERR", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "magd.2");
    pdump(infile="mag.2", fields="XCENTER,YCENTER", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "xycood.2")
  }

  if (access("mag.3")) {
    pdump(infile="mag.3", fields="MAG,MERR", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "magd.3");
    pdump(infile="mag.3", fields="XCENTER,YCENTER", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "xycood.3")
  }

  if (access("mag.4")) {
    pdump(infile="mag.4", fields="MAG,MERR", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "magd.4");
    pdump(infile="mag.4", fields="XCENTER,YCENTER", expr="FLUX > 0. && PIER == 0 && PERROR ?= 'NoError'", head-, par-, > "xycood.4")
  }

end
