#
#  Script for producing photometry from cleaned images
#
#  This script is a wrapper - see each script for inputs
#  and outputs
#
#  Works on any of 4 IRAC channels
#
# (c) 2005 Mike Schuster (mschuster@cfa.harvard.edu)
# (c) 2005 SAO - Smithsonian Astrophysical Observatory
#
#  v1.2 - 10 JAN 2006
#  several previous versions by several authors, SAO
#

procedure run_nsphot (filename, exptime, dmin1, dmin2, dmin3, dmin4, dmax1, dmax2, dmax3, dmax4, sig1, sig2, sig3, sig4)

string filename {prompt="File Name"}
real exptime {1, prompt="Exposure Time"}
real dmin1 {INDEF, prompt="ch1 data min"}
real dmin2 {INDEF, prompt="ch2 data min"}
real dmin3 {INDEF, prompt="ch3 data min"}
real dmin4 {INDEF, prompt="ch4 data min"}
real dmax1 {INDEF, prompt="ch1 data max"}
real dmax2 {INDEF, prompt="ch2 data max"}
real dmax3 {INDEF, prompt="ch3 data max"}
real dmax4 {INDEF, prompt="ch4 data max"}
real sig1 {INDEF, prompt="ch1 sky sigma"}
real sig2 {INDEF, prompt="ch2 sky sigma"}
real sig3 {INDEF, prompt="ch3 sky sigma"}
real sig4 {INDEF, prompt="ch4 sky sigma"}

begin

    string name
    real expt
    real sc1
    real sc2
    real sc3
    real sc4
    real dmi1
    real dmi2
    real dmi3
    real dmi4
    real dma1
    real dma2
    real dma3
    real dma4
    real s1
    real s2
    real s3
    real s4

    name = filename
    expt = exptime
    sc1 = expt * 3.3
    sc2 = expt * 3.71
    sc3 = expt * 3.8
    sc4 = expt * 3.8
    dmi1 = dmin1
    dmi2 = dmin2
    dmi3 = dmin3
    dmi4 = dmin4
    dma1 = dmax1
    dma2 = dmax2
    dma3 = dmax3
    dma4 = dmax4
    s1 = sig1
    s2 = sig2
    s3 = sig3
    s4 = sig4

    unlearn("do_nsfind")
    unlearn("psort_xy")
    unlearn("pdump_xy")
    unlearn("do_nsphot")
    unlearn("pdump_xymag")
    unlearn("do_wcsctran")

    # Find sources
    do_nsfind(filename=name, dmin1=dmi1, dmin2=dmi2, dmin3=dmi3, dmin4=dmi4, dmax1=dma1, dmax2=dma2, dmax3=dma3, dmax4=dma4, sig1=s1, sig2=s2, sig3=s3, sig4=s4)

    # Sort source list based on x-coordinate
    psort_xy(fld="XCENTER")

    # Copy source coordinates to list
    pdump_xy

    # Do photometry
    do_nsphot(filename=name, scale1=sc1, scale2=sc2, scale3=sc3, scale4=sc4, dmin1=dmi1, dmin2=dmi2, dmin3=dmi3, dmin4=dmi4, dmax1=dma1, dmax2=dma2, dmax3=dma3, dmax4=dma4, sig1=s1, sig2=s2, sig3=s3, sig4=s4)

    # Copy "good" source magnitudes, errors, and coordinates to lists
    pdump_xymag

    # Find WCS coordinates of "good" sources
    do_wcsctran(filename=name)

end
